<?php # $Id: serendipity_lang_fr.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translation by Sebastian Mordziol <argh@php-tools.net>
# http://sebastian.mordziol.de
# Traduction complte par Andr San-Martin <andre.sanmartin@free.fr>
# http://www.sossan-martin.com
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'ISO-8859-1');
@define('SQL_CHARSET', 'latin1');
@define('DATE_LOCALES', 'fr_FR.ISO-8859-1, fr_FR.ISO8859-1, french, fr, fr_FR, fr_FR@euro, en_US');
@define('DATE_FORMAT_ENTRY', '%A, %e %B %Y');
@define('DATE_FORMAT_SHORT', '%d.%m.%Y %H:%M');
@define('WYSIWYG_LANG', 'fr');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', '.');
@define('NUMBER_FORMAT_THOUSANDS', ',');
@define('LANG_DIRECTION', 'ltr');

@define('SERENDIPITY_ADMIN_SUITE', 'Administration de Serendipity');
@define('HAVE_TO_BE_LOGGED_ON', 'Vous devez tre authentifi pour accder  cette page');
@define('WRONG_USERNAME_OR_PASSWORD', 'Vous avez entr un nom d\'utilisateur ou un mot de passe erron');
@define('APPEARANCE', 'Apparence');
@define('MANAGE_STYLES', 'Configurer les Styles');
@define('CONFIGURE_PLUGINS', 'Configurer les Plugins');
@define('CONFIGURATION', 'Configuration');
@define('BACK_TO_BLOG', 'Revenir au Weblog');
@define('LOGIN', 'Se connecter');
@define('LOGOUT', 'Se dconnecter');
@define('LOGGEDOUT', 'Dconnect.');
@define('CREATE', 'Crer');
@define('SAVE', 'Enregistrer');
@define('NAME', 'Nom');
@define('CREATE_NEW_CAT', 'Crer une nouvelle catgorie');
@define('I_WANT_THUMB', 'Je veux utiliser une miniature dans ma news.');
@define('I_WANT_BIG_IMAGE', 'Je veux utiliser l\'image en taille rlle dans mon billet.');
@define('I_WANT_NO_LINK', ' Je veux l\'afficher en tant qu\'image');
@define('I_WANT_IT_TO_LINK', 'Je veux l\'afficher en tant que lien vers cette adresse :');
@define('BACK', 'Prcdent');
@define('FORWARD', 'Suivant');
@define('ANONYMOUS', 'Anonyme');
@define('NEW_TRACKBACK_TO', 'Nouveau rtrolien fait sur');
@define('NEW_COMMENT_TO', 'Nouveau commentaire post sur');
@define('RECENT', 'Rcentes...');
@define('OLDER', 'Plus anciennes...');
@define('DONE', 'Effectu');
@define('WELCOME_BACK', 'Bienvenue,');
@define('TITLE', 'Titre');
@define('DESCRIPTION', 'Description');
@define('PLACEMENT', 'Emplacement');
@define('DELETE', 'Supprimer');
@define('SAVE', 'Enregistrer');
@define('UP', '+HAUT');
@define('DOWN', '+BAS');
@define('ENTRIES', 'billets');
@define('NEW_ENTRY', 'Poster un billet');
@define('EDIT_ENTRIES', 'diter les billets');
@define('CATEGORIES', 'Catgories');
@define('WARNING_THIS_BLAHBLAH', "ATTENTION:\\nCeci peut prendre du temps s\'il y beaucoup d\'images sans miniatures.");
@define('CREATE_THUMBS', 'Recrer les miniatures');
@define('MANAGE_IMAGES', 'Configurer les images');
@define('NAME', 'Nom');
@define('EMAIL', 'Email');
@define('HOMEPAGE', 'Site');
@define('COMMENT', 'Commentaire');
@define('REMEMBER_INFO', 'Enregistrer ces informations ?');
@define('SUBMIT_COMMENT', 'Poster le commentaire');
@define('NO_ENTRIES_TO_PRINT', 'Aucun billet  afficher');
@define('COMMENTS', 'Commentaires');
@define('ADD_COMMENT', 'Ajouter un commentaire');
@define('NO_COMMENTS', 'Pas de commentaires');
@define('POSTED_BY', 'Post par');
@define('ON', 'sur');
@define('A_NEW_COMMENT_BLAHBLAH', 'Un nouveau commentaire a t post sur votre blog "%s", pour le billet intitul "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', 'Un nouveau rtrolien a t fait sur votre blog au billet intitul "%s".');
@define('NO_CATEGORY', 'Pas de Catgorie');
@define('ENTRY_BODY', 'Introduction');
@define('EXTENDED_BODY', 'Corps du billet');
@define('CATEGORY', 'Catgorie');
@define('EDIT', 'diter');
@define('NO_ENTRIES_BLAHBLAH', 'Aucun billet trouv pour la requte %s' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'Votre recherche pour %s a donn %s rsultats :');
@define('IMAGE', 'Image');
@define('ERROR_FILE_NOT_EXISTS', 'Erreur : Ce fichier n\'existe pas.');
@define('ERROR_FILE_EXISTS', 'Erreur : il existe dj un fichier portant ce nom. Choisissez un nouveau nom.');
@define('ERROR_SOMETHING', 'Erreur : quelque chose ne va pas.');
@define('ADDING_IMAGE', 'Ajout d\'une image...');
@define('THUMB_CREATED_DONE', 'Miniature cree.<br>Termin.');
@define('ERROR_FILE_EXISTS_ALREADY', 'Erreur : le fichier existe dj sur votre machine.');
@define('GO', 'Go!');
@define('NEWSIZE', 'Nouvelle taille : ');
@define('RESIZE_BLAHBLAH', '<b>Redimensionner %s</b><p>');
@define('ORIGINAL_SIZE', 'Taille d\'origine : <i>%sx%s</i> pixel');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Ici vous pouvez ajuster la taille de l\'image slectionne. Si vous voulez respecter les proportions de l\'image, entrez juste la hauteur ou la largeur, et pressez la touche TAB - la valeur correspondante sera insre automatiquement :');
@define('QUICKJUMP_CALENDAR', 'Saut rapide vers le Calendrier');
@define('QUICKSEARCH', 'Recherche rapide');
@define('SEARCH_FOR_ENTRY', 'Recherche d\'un billet');
@define('ARCHIVES', 'Archives');
@define('BROWSE_ARCHIVES', 'Afficher les archives par mois');
@define('TOP_REFERRER', 'Top des liens entrants');
@define('SHOWS_TOP_SITES', 'Montrer le top des sites qui affichent un lien vers votre blog');
@define('TOP_EXITS', 'Top des liens sortants');
@define('SHOWS_TOP_EXIT', 'Montrer le top des liens de sites qui sortent de votre blog');
@define('SYNDICATION', 'Syndication');
@define('SHOWS_RSS_BLAHBLAH', 'Montrer les liens de syndication RSS');
@define('ADVERTISES_BLAHBLAH', 'Publicit sur l\'origine de votre blog');
@define('HTML_NUGGET', 'Bloc HTML');
@define('HOLDS_A_BLAHBLAH', 'Permet d\'afficher des contenus personnaliss au format HTML dans la barre latrale');
@define('TITLE_FOR_NUGGET', 'Titre du bloc HTML');
@define('THE_NUGGET', 'Contenu du bloc HTML');
@define('SYNDICATE_THIS_BLOG', 'Syndiquer ce Blog');
@define('YOU_CHOSE', 'Vous avez choisi %s');
@define('IMAGE_SIZE', 'Taille de l\'image');
@define('IMAGE_AS_A_LINK', 'Insrer l\'image');
@define('POWERED_BY', 'propuls par');
@define('TRACKBACKS', 'Rtroliens');
@define('TRACKBACK', 'Rtrolien');
@define('NO_TRACKBACKS', 'Pas de rtroliens');
@define('TOPICS_OF', 'Sujets de');
@define('VIEW_FULL', 'Voir la totalit');
@define('VIEW_TOPICS', 'Voir les sujets');
@define('AT', '');
@define('SET_AS_TEMPLATE', 'Choisir ce thme');
@define('IN', 'dans');
@define('EXCERPT', 'Except');
@define('TRACKED', 'Suivi');
@define('LINK_TO_ENTRY', 'Liens vers le billet');
@define('LINK_TO_REMOTE_ENTRY', 'Lien vers le billet externe');
@define('IP_ADDRESS', 'Adresse IP');
@define('USER', 'Utilisateur');
@define('THUMBNAIL_USING_OWN', 'L\'image %s est si petite qu\'elle va tre utilise comme sa propre miniature.');
@define('THUMBNAIL_FAILED_COPY', 'La miniature pour %s n\'a pas pu tre copie.');
@define('AUTHOR', 'Auteur');
@define('LAST_UPDATED', 'Dernire mise  jour');
@define('TRACKBACK_SPECIFIC', 'Rtrolien spcifique pour ce billet');
@define('DIRECT_LINK', 'Lien direct  ce billet');
@define('COMMENT_ADDED', 'Votre commentaire a t ajout.');
@define('COMMENT_ADDED_CLICK', 'Cliquez %sici pour retourner%s aux commentaires, et %sici pour fermer%s cette fentre.');
@define('COMMENT_NOT_ADDED_CLICK', 'Cliquez %sici pour retourner%s aux commentaires, et %sici pour fermer%s cette fentre.');
@define('COMMENTS_DISABLE', 'Ne pas autoriser de commentaires pour ce billet');
@define('COMMENTS_ENABLE', 'Autoriser les commentaires pour ce billet');
@define('COMMENTS_CLOSED', 'L\'auteur n\'a pas autoris l\'ajout de commentaires pour ce billet.');
@define('EMPTY_COMMENT', 'Votre commentaire est vide, %sretournez en arrire%s et ressayez');
@define('ENTRIES_FOR', 'Billets pour %s');
@define('DOCUMENT_NOT_FOUND', 'Le document %s n\'a pas t trouv.');
@define('USERNAME', 'Nom d\'utilisateur');
@define('PASSWORD', 'Mot de passe');
@define('AUTOMATIC_LOGIN', 'Garder en mmoire');
@define('SERENDIPITY_INSTALLATION', 'Installation de Serendipity');
@define('LEFT', 'gauche');
@define('RIGHT', 'droite');
@define('HIDDEN', 'cach');
@define('REMOVE_TICKED_PLUGINS', 'Supprimer les plugins cochs');
@define('SAVE_CHANGES_TO_LAYOUT', 'Enregistrer les changements');
@define('COMMENTS_FROM', 'Commentaires de');
@define('ERROR', 'Erreur');
@define('DELETE_SURE', 'Etes vous sr de vouloir supprimer #%s dfinitivement ?');
@define('NOT_REALLY', 'Pas vraiment...');
@define('DUMP_IT', ' la poubelle !');
@define('RIP_ENTRY', 'Le billet #%s a rejoint l\'ternel.');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Catgorie #%s supprime. Les billets ont t dplacs dans la catgorie #%s');
@define('CATEGORY_DELETED', 'Catgorie #%s supprime.');
@define('INVALID_CATEGORY', 'Aucune catgorie slectionne pour la suppression');
@define('CATEGORY_SAVED', 'Catgorie sauvegarde');
@define('SELECT_TEMPLATE', 'Slectionnez le thme que vous voulez utiliser pour votre blog');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'Les billets n\'ont pas pu tre imports.');
@define('YES', 'Oui');
@define('NO', 'Non');
@define('USE_DEFAULT', 'Default');
@define('CHECK_N_SAVE', 'Vrifier &amp; sauvegarder');
@define('DIRECTORY_WRITE_ERROR', 'Je ne peux pas crire dans le rpertoire %s. Il faudrait que vous me donniez les droits d\'accs ncessaires manuellement.');
@define('DIRECTORY_CREATE_ERROR', 'Le rpertoire %s n\'existe pas et ne peut pas tre cre automatiquement. Veuillez le crer manuellement, ou me donner les droits d\'accs ncessaires.');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; excute <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', 'Je ne peux pas excuter le programme %s');
@define('FILE_WRITE_ERROR', 'Je ne peux pas ouvrir le fichier %s pour criture.');
@define('FILE_CREATE_YOURSELF', 'Merci de crer le fichier vous-mme ou de me donner les droits d\'accs ncessaires.');
@define('COPY_CODE_BELOW', '<br />* Copiez le code ci-dessous et placez le %s dans votre %s rpertoire :<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'Changez www dans le nom d\'utilisateur sous lequel fonctionne le serveur apache (nobody, par ex).');
@define('BROWSER_RELOAD', 'Une fois ceci effectu, rechargez la page avec la touche "F5".');
@define('DIAGNOSTIC_ERROR', 'J\'ai touv quelques erreurs en vrifiant vos donnes :');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity n\'est pas encore install. Vous pouvez <a href="%s">l\'installer maintenant</a>.');
@define('INCLUDE_ERROR', 'Erreur Serendipity : impossible d\'inclure le fichier %s.');
@define('DATABASE_ERROR', 'Erreur Serendipity : impossible d\'ouvrir une connexion avec la base de donnes.');
@define('CREATE_DATABASE', 'Cration de la structure de la base de donnes...');
@define('ATTEMPT_WRITE_FILE', 'Essai d\'criture sur le fichier %s...');
@define('WRITTEN_N_SAVED', 'Configuration crite &amp; sauvegarde');
@define('IMAGE_ALIGNMENT', 'Position de l\'image');
@define('ENTER_NEW_NAME', 'Entrez le nouveau nom pour : ');
@define('RESIZING', 'Redimensionnement');
@define('RESIZE_DONE', 'Termin (%s images redimensionnes).');
@define('SYNCING', 'Synchronisation de la base de donnes avec votre collection d\'images');
@define('SYNC_DONE', 'Termin (%s images synchronises).');
@define('DELETE_IMAGE_FAIL' , 'Impossible de supprimer l\'image intitule <b>%s</b>');
@define('DELETE_THUMBNAIL', 'Suppression de la miniature de l\'image intitule <b>%s</b>');
@define('FILE_NOT_FOUND', 'Impossible de trouver le fichier intitul <b>%s</b>, peut-tre a-t-il dj t supprim ?');
@define('ABORT_NOW', 'Annuler maintenant');
@define('REMOTE_FILE_NOT_FOUND', 'Le fichier n\'a pas t trouv sur le serveur distant, tes-vous sr que l\'URL <b>%s</b> est correcte ?');
@define('FILE_FETCHED', '%s tlcharg et sauvegard sous %s');
@define('FILE_UPLOADED', 'Le fichier %s a t upload avec succs sous %s');
@define('WORD_OR', 'Ou');
@define('SCALING_IMAGE', 'Redimensionnement %s en %s x %s px');
@define('KEEP_PROPORTIONS', 'Conserver les proportions');
@define('REALLY_SCALE_IMAGE', 'Rellement redimensionner cette image ? Attention : cette opration est irrversible !');
@define('TOGGLE_ALL', 'Afficher/Ne pas afficher les dtails');
@define('TOGGLE_OPTION', 'Afficher les dtails');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'Souscrire  ce billet');
@define('UNSUBSCRIBE_OK', "%s est maintenant dsinscrit de cette news");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'Nouveau commentaire post  votre souscription du billet "%s"');
@define('SUBSCRIPTION_MAIL', "Bonjour %s,\n\nUn nouveau commentaire a t post au billet que vous surveillez \"%s\", intitul \"%s\"\nLe pseudo de l\'auteur est : %s\n\nVous pouvez trouver le billet ici : %s\n\nVous pouvez vous dsinscrire en cliquant sur ce lien : %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "Bonjour %s,\n\nUn nouveau rtrolien a t ajout au billet que vous surveillez \"%s\", intitul \"%s\"\nLe pseudo de l\'auteur est : %s\n\nVous pouvez trouver le billet ici : %s\n\nVous pouvez vous dsinscrire en cliquant sur ce lien : %s\n");
@define('SIGNATURE', "\n-- \n%s est propuls par Serendipity.\nLe blog des blogs que vous aussi pouvez utiliser !\nAllez sur <http://s9y.org>, le site officiel.");
@define('SYNDICATION_PLUGIN_091', 'RSS 0.91');
@define('SYNDICATION_PLUGIN_10', 'RSS 1.0');
@define('SYNDICATION_PLUGIN_20', 'RSS 2.0');
@define('SYNDICATION_PLUGIN_20c', 'Commentaires RSS 2.0');
@define('SYNDICATION_PLUGIN_ATOM03', 'ATOM 0.3');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', 'Champs "managingEditor"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  'Champs "webMaster"');
@define('SYNDICATION_PLUGIN_BANNERURL', 'Image pour le fil RSS');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'Largeur d\'image');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'Hauteur d\'image');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  'Adresse E-Mail du webmaster, si disponible. (aucun : invisible) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'Adresse E-Mail de l\'diteur principal, si disponible. (aucun : invisible) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'Adresse d\'une image au format GIF/JPEG/PNG, si disponible. (aucune : logo serendipity)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'en pixels, maximum 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'en pixels, maximum 400');
@define('SYNDICATION_PLUGIN_TTL', 'Champs "ttl" (time-to-live = temps  vivre)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'Laps de temps en minutes aprs lequel votre blog ne doit plus tre pris du cache par des sites/programmes externes (aucun : invisible) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', 'Champs "pubDate"');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'Inclure le champs "pubDate" dans le fil RSS pour afficher la date du billet le plus rcent ?');
@define('CONTENT', 'Contenu');
@define('TYPE', 'Type');
@define('DRAFT', 'Brouillon');
@define('PUBLISH', 'Publication');
@define('PREVIEW', 'Prvisualisation');
@define('DATE', 'Date');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Doit etre compatible ISO 8601 pour la conversion de date !
@define('DATE_INVALID', 'Attention: La date entre est invalide. Elle doit tre au format YYYY-MM-DD HH:MM .');
@define('CATEGORY_PLUGIN_DESC', 'Affiche la liste des catgories.');
@define('ALL_AUTHORS', 'Tous les auteurs');
@define('CATEGORIES_TO_FETCH', 'Catgories  afficher');
@define('CATEGORIES_TO_FETCH_DESC', 'Afficher les catgories par auteur(s) spcifique(s)');
@define('PREVIOUS_PAGE', 'Page prcdente');
@define('NEXT_PAGE', 'Page suivante');
@define('ALL_CATEGORIES', 'Toutes les catgories');
@define('DO_MARKUP', 'Transformation de balises dans le texte');
@define('GENERAL_PLUGIN_DATEFORMAT', 'Format de la date');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'Le format dans lequel la date des billets doit tre affiche. Toute syntaxe permise par la fonction PHP <a href="http://www.php.net/strftime" target="blank">strftime()</a> est possible. (Dfaut : "%s")');
@define('ERROR_TEMPLATE_FILE', 'Impossible d\'ouvrir le fichier du thme, merci de mettre  jour Serendipity !');
@define('ADVANCED_OPTIONS', 'Options avances');
@define('EDIT_ENTRY', 'diter le billet');
@define('HTACCESS_ERROR', 'Pour vrifier l\'installation de Serendipity sur votre serveur, Serendipity doit pouvoir crer le fichier ".htaccess". Ceci n\'a pas t possible car Serendipity n\'a pas les droits d\'accs suffisants dans ce rpertoire. Vous pouvez ajuster les droits d\'accs avec la commande suivante : <br />&nbsp;&nbsp;%s<br />. Aprs, rechargez cette page avec la touche "F5".');
@define('SIDEBAR_PLUGINS', 'Plugins pour la barre latrale');
@define('EVENT_PLUGINS', 'Plugins d\'vnement');
@define('SORT_ORDER', 'Trier par ordre');
@define('SORT_ORDER_NAME', 'Nom du fichier');
@define('SORT_ORDER_EXTENSION', 'Extension du fichier');
@define('SORT_ORDER_SIZE', 'Taille du fichier');
@define('SORT_ORDER_WIDTH', 'Largeur de l\'image');
@define('SORT_ORDER_HEIGHT', 'Hauteur de l\'image');
@define('SORT_ORDER_DATE', 'Date de l\'upload');
@define('SORT_ORDER_ASC', 'Croissant');
@define('SORT_ORDER_DESC', 'Dcroissant' );
@define('THUMBNAIL_SHORT', 'Miniature');
@define('ORIGINAL_SHORT', 'Orig.');
@define('APPLY_MARKUP_TO', 'Appliquer la transformation des balises  %s');
@define('CALENDAR_BEGINNING_OF_WEEK', 'Dbut de la semaine');
@define('SERENDIPITY_NEEDS_UPGRADE', 'Serendipity a dtect que votre configuration (version %s) ne correspond pas  la version de votre installation de Serendipity (version %s). Pour continuer  utiliser Serendipity, l\'assistant de mise  jour va vous guider pour <a href="%s">mettre  jour</a> votre installation.');
@define('SERENDIPITY_UPGRADER_WELCOME', 'Bonjour, et bienvenue dans l\'assistant de mise  jour de Serendipity.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'Je vais vous guider pour la mise  jour de votre installation %s de Serendipity.');
@define('SERENDIPITY_UPGRADER_WHY', 'Vous voyez ce message car vous avez install Serendipity %s, mais la base de donnes doit tre reconfigure pour fonctionner correctement avec cette version.');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Mises  jour de la base de donnes (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'Pour mettre  jour votre base de donnes, j\'ai trouv les fichiers .sql suivants qui doivent tre imports :');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'Tches spcifiques  la version');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'Aucune tche spcifique  la nouvelle version n\'a t trouve');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'Voulez-vous que j\'effectue les tches suivantes ?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'Non, je vais le faire manuellement');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'Oui, faites-le s\'il vous plait');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'Une mise  jour n\'est pas ncessaire pour votre installation de Serendipity, il n\'y a pas de tches  effectuer.');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Considrez Serendipity comme mis  jour.');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'Vous avez ignor la mise  jour de Serendipity, assurez-vous que la base de donnes est installe correctement, et que les tches ncessaires sont effectues.');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'Votre installation de Serendipity a t mise  jour  la version %s.');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'Vous pouvez retourner  votre blog en %scliquant ici%s');
@define('MANAGE_USERS', 'Administrer les utilisateurs');
@define('CREATE_NEW_USER', 'Crer un nouvel utilisateur');
@define('CREATE_NOT_AUTHORIZED', 'Vous ne pouvez pas diter des utilisateurs qui ont le mme niveau d\'autorisation que le vtre.');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', 'Vous ne pouvez pas crer d\'utilisateur avec un niveau d\'autorisation plus lev que le vtre.');
@define('CREATED_USER', 'Un nouvel utilisateur %s a t cr');
@define('MODIFIED_USER', 'Les proprits de l\'utilisateur %s ont t changes');
@define('USER_LEVEL', 'Niveau d\'autorisation');
@define('DELETE_USER', 'Vous tes sur le point de supprimer l\'utilisateur #%d %s. tes-vous sr de vouloir continuer ? Les billets de cet utilisateur ne seront plus visibles dans votre blog.');
@define('DELETED_USER', 'Utilisateur #%d %s supprim.');
@define('LIMIT_TO_NUMBER', 'Limiter le nombre de billets  ?');
@define('ENTRIES_PER_PAGE', 'billets par page');
@define('XML_IMAGE_TO_DISPLAY', 'Bouton "XML"');
@define('XML_IMAGE_TO_DISPLAY_DESC','Les liens vers les fils XML seront affichs avec cette image. Laissez vide pour l\'image par dfaut, ou tapez \'none\' pour la dsactiver.');

@define('DIRECTORIES_AVAILABLE', 'Dans la liste des sous-dossiers disponibles, vous pouvez cliquer sur un nom de dossier pour en crer un nouveau  cet endroit.');
@define('ALL_DIRECTORIES', 'tous les dossiers');
@define('MANAGE_DIRECTORIES', 'Administrer les dossiers');
@define('DIRECTORY_CREATED', 'Le dossier <strong>%s</strong> a t cr.');
@define('PARENT_DIRECTORY', 'Dossier parent');
@define('CONFIRM_DELETE_DIRECTORY', 'tes-vous sr de vouloir supprimer tous les contenus du dossier %s ?');
@define('ERROR_NO_DIRECTORY', 'Erreur : le dossier %s n\'existe pas');
@define('CHECKING_DIRECTORY', 'Vrification des fichiers dans le dossier %s');
@define('DELETING_FILE', 'Suppression du fichier %s...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'Impossible de supprimer un dossier non vide. Cochez la case "Forcer la suppression" si vous voulez supprimer les fichiers gnants, et puis effectuez l\'opration  nouveau. Les fichiers prsents dans le dossier sont les suivants :');
@define('DIRECTORY_DELETE_FAILED', 'La suppression du dossier %s a chou. Vrifiez les droits d\'accs au rpertoire et les messages ci-dessus.');
@define('DIRECTORY_DELETE_SUCCESS', 'Suppression du dossier %s effectue.');
@define('SKIPPING_FILE_EXTENSION', 'Fichier ignor : pas d\'extension de fichier dans %s.');
@define('SKIPPING_FILE_UNREADABLE', 'Fichier ignor : impossible de lire  partir du fichier %s .');
@define('FOUND_FILE', 'Fichier nouveau/modifi trouv : %s.');
@define('ALREADY_SUBCATEGORY', '%s est dj une sous-catgorie de %s.');
@define('PARENT_CATEGORY', 'Catgorie parent');
@define('IN_REPLY_TO', 'En rponse ');
@define('TOP_LEVEL', 'Racine');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'Configuration de la base de donnes');
@define('INSTALL_CAT_DB_DESC', 'Vous permet d\'entrer toutes les donnes ncessaires pour la base de donnes dont Serendipity a besoin pour fonctionner.');
@define('INSTALL_DBTYPE', 'Type de base de donnes');
@define('INSTALL_DBTYPE_DESC', 'Choisissez le type de votre base de donnes');
@define('INSTALL_DBHOST', 'Serveur hte');
@define('INSTALL_DBHOST_DESC', 'Le nom du serveur hte sur lequel rside la base de donnes (exemple: localhost)');
@define('INSTALL_DBUSER', 'Nom d\'utilisateur');
@define('INSTALL_DBUSER_DESC', 'Le nom d\'utilisateur  utiliser pour se connecter  la base de donnes');
@define('INSTALL_DBPASS', 'Mot de passe');
@define('INSTALL_DBPASS_DESC', 'Le mot de passe correspondant au nom d\'utilisateur');
@define('INSTALL_DBNAME', 'Nom de la base de donnes');
@define('INSTALL_DBNAME_DESC', 'Le nom de la base de donnes  laquelle Serendipity doit se connecter');
@define('INSTALL_DBPREFIX', 'Prfixe des tables');
@define('INSTALL_DBPREFIX_DESC', 'Le prfixe  utiliser pour les tables de Serendipity (exemple: serendipity_)');

/* PATHS */
@define('INSTALL_CAT_PATHS', 'Chemins');
@define('INSTALL_CAT_PATHS_DESC', 'Configuration des chemins aux dossiers et fichiers indispensables. N\'oubliez pas d\'ajouter les slashes ("/") finaux !');
@define('INSTALL_FULLPATH', 'Chemin absolu');
@define('INSTALL_FULLPATH_DESC', 'Le chemin complet et absolu du dossier d\'installation de Serendipity');
@define('INSTALL_UPLOADPATH', 'Chemin pour les uploads');
@define('INSTALL_UPLOADPATH_DESC', 'C\'est ici que Serendipity enregistre tous les fichiers uploads. Chemin relatif au \'chemin absolu\' - normalement \'uploads/\'');
@define('INSTALL_RELPATH', 'Chemin relatif');
@define('INSTALL_RELPATH_DESC', 'Le chemin d\'accs  Serendipity pour votre navigateur, normalement \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', 'Chemin relatif des thmes');
@define('INSTALL_RELTEMPLPATH_DESC', 'Le chemin au dossier contenant vos thmes - relatif au \'Chemin relatif\'');
@define('INSTALL_RELUPLOADPATH', 'Chemin relatif des uploads');
@define('INSTALL_RELUPLOADPATH_DESC', 'Le chemin d\'accs aux fichiers uploads pour votre navigateur - relatif au \'Chemin relatif\'');
@define('INSTALL_URL', 'Lien au blog');
@define('INSTALL_URL_DESC', 'Le lien (URL) pour accder  votre installation de Serendipity');
@define('INSTALL_INDEXFILE', 'Script principal');
@define('INSTALL_INDEXFILE_DESC', 'Le nom du script principal que vous voulez utiliser pour Serendipity (exemple: index.php)');

/* General settings */
@define('INSTALL_CAT_SETTINGS', 'Configuration gnrale');
@define('INSTALL_CAT_SETTINGS_DESC', 'Personnalisation et configuration gnrale de Serendipity');
@define('INSTALL_USERNAME', 'Nom de l\'administrateur');
@define('INSTALL_USERNAME_DESC', 'Le nom d\'utilisateur pour l\'accs de l\'administrateur');
@define('INSTALL_PASSWORD', 'Mot de passe l\'administrateur');
@define('INSTALL_PASSWORD_DESC', 'Le mot de passe pour l\'accs de l\'administrateur');
@define('INSTALL_EMAIL', 'Email de l\'administrateur');
@define('INSTALL_EMAIL_DESC', 'Adresse Email  utiliser pour l\'administrateur du blog');
@define('INSTALL_SENDMAIL', 'Envoi d\'emails  l\'administrateur ?');
@define('INSTALL_SENDMAIL_DESC', 'Voulez-vous que l\'administrateur reoive un email quand des commentaires sont posts dans les billets ?');
@define('INSTALL_SUBSCRIBE', 'Autoriser les utilisateurs  suivre des billets ?');
@define('INSTALL_SUBSCRIBE_DESC', 'Donner aux utilisateurs la possibilit de souscrire  un billet, et ainsi recevoir des emails quand des commentaires sont posts dans celui-ci ?');
@define('INSTALL_BLOGNAME', 'Titre du blog');
@define('INSTALL_BLOGNAME_DESC', 'Le titre de votre blog');
@define('INSTALL_BLOGDESC', 'Description de votre blog');
@define('INSTALL_BLOGDESC_DESC', 'La description de votre blog');
@define('INSTALL_LANG', 'Langue');
@define('INSTALL_LANG_DESC', 'Choisissez la langue  utiliser pour votre blog. Celle-ci sera utilise dans le blog et l\'interface d\'administration.');

/* Appearance and options */
@define('INSTALL_CAT_DISPLAY', 'Apparence et options');
@define('INSTALL_CAT_DISPLAY_DESC', 'Personnalisation du \'look &amp; feel\' de l\'interface du blog.');
@define('INSTALL_WYSIWYG', 'Utiliser l\'diteur WYSIWYG');
@define('INSTALL_WYSIWYG_DESC', 'Voulez-vous utiliser l\'diteur WYSIWYG pour composer vos billets ? (Fonctionne avec IE5+, et partiellement avec Mozilla 1.3+)');
@define('INSTALL_XHTML11', 'Forcer la conformit XHTML 1.1');
@define('INSTALL_XHTML11_DESC', 'Voulez-vous forcer la conformit au standard XHTML 1.1 (peut causer des problmes au niveau de l\'administration et du blog dans les navigateurs plus anciens de la 4me gnration)');
@define('INSTALL_POPUP', 'Activer les fentres pop-pup');
@define('INSTALL_POPUP_DESC', 'Voulez-vous que le blog utilise des fentres pop-up pour les commentaires, traages et autres ?');
@define('INSTALL_EMBED', 'Intgration dans une application externe');
@define('INSTALL_EMBED_DESC', 'Si vous voulez intgrer Serendipity dans une page normale ou dans une application externe, choisissez \'Oui\'. Serendipity n\'affichera alors que les contenus du blog, vous permettant de les intgrer facilement dans n\'importe quelle page. Vous pouvez aussi utiliser l\'option \'Script principal\' pour crer un encapsulateur (wrapper) qui vous permettra d\'ajouter vos propres contenus et visuels. Pour plus d\'informations sur l\'intgration de Serendipity, consultez le fichier README fourni dans l\'installation.');
@define('INSTALL_BLOCKREF', 'Exclure des pages rfrantes');
@define('INSTALL_BLOCKREF_DESC', 'Vous pouvez exclure des noms de domaine spcifiques de la liste des pages rfrantes : sparez chaque nom de domaine avec \';\', et notez que l\'exclusion du nom de domaine se fait par la fonction <a href="http://www.php.net/substring" target="_blank">substring()</a>.');
@define('INSTALL_REWRITE', 'Recritures URL');
@define('INSTALL_REWRITE_DESC', 'Choisissez la mthode  utiliser pour la gestion des URL de votre blog. Si vous activez les rcritures URL, l\'accs  votre blog se fera par des URL simples, plus facilement indexables par les moteurs de recherche. Pour les activer, le module mod_rewrite doit tre activ dans votre serveur, ou il doit autoriser l\'utilisation de la directive "AllowOverride All" pour le dossier d\'installation de Serendipity. Par dfaut Serendipity choisit automatiquement l\'option  utiliser.');

/* Imageconversion Settings */
@define('INSTALL_CAT_IMAGECONV', 'Options de gestion des images');
@define('INSTALL_CAT_IMAGECONV_DESC', 'Dfinissez comment Serendipity doit grer les transformations/conversions d\'images dans votre mdiathque.');
@define('INSTALL_IMAGEMAGICK', 'Utiliser Imagemagick');
@define('INSTALL_IMAGEMAGICK_DESC', 'Est-ce que imageMagick est install sur votre serveur, et voulez-vous l\'utiliser pour le redimensionnement de vos images?');
@define('INSTALL_IMAGEMAGICKPATH', 'Chemin d\'accs au programme de conversion');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'Chemin absolu et nom de votre programme de conversion de imageMagick (normalement \'convert\')');
@define('INSTALL_THUMBSUFFIX', 'Suffixe pour les miniatures');
@define('INSTALL_THUMBSUFFIX_DESC', 'Les miniatures d\'images seront enregistres de la manire suivante : original.[suffixe].ext');
@define('INSTALL_THUMBWIDTH', 'Dimensions des miniatures');
@define('INSTALL_THUMBWIDTH_DESC', 'Largeur maximum (statique) des miniatures cres automatiquement');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', 'Dtails personnels');
@define('USERCONF_CAT_PERSONAL_DESC', 'Dtails sur votre compte personnel');
@define('USERCONF_USERNAME', 'Votre nom d\'utilisateur');
@define('USERCONF_USERNAME_DESC', 'Votre nom d\'utilisateur');
@define('USERCONF_PASSWORD', 'Votre mot de passe');
@define('USERCONF_PASSWORD_DESC', 'Votre mot de passe');
@define('USERCONF_EMAIL', 'Votre E-Mail');
@define('USERCONF_EMAIL_DESC', 'Votre E-Mail');
@define('USERCONF_SENDCOMMENTS', 'Notification de commentaire ?');
@define('USERCONF_SENDCOMMENTS_DESC', 'Voulez-vous recevoir un email lorsque quelqu\'un poste un commentaire dans votre billet ?');
@define('USERCONF_SENDTRACKBACKS', 'Notification de rtroliens ?');
@define('USERCONF_SENDTRACKBACKS_DESC', 'Voulez-vous recevoir un email lorsque quelqu\'un cre un rtrolien  l\'un de vos billets ?');

@define('PERMISSIONS', 'Permissions');
@define('USERCONF_ALLOWPUBLISH', 'Publication de billets ?');
@define('USERCONF_ALLOWPUBLISH_DESC', 'Cet utilisateur est-il autoris  poster des billets ?');
@define('ENTRY_SAVED', 'Votre billet a t enregistr');
@define('SUCCESS', 'Succs');
@define('POWERED_BY_SHOW_TEXT', 'Afficher \'Serendipity\' en tant que texte');
@define('POWERED_BY_SHOW_TEXT_DESC', 'Affiche le slogan \'Serendipity Weblog\' en tant que texte');
@define('POWERED_BY_SHOW_IMAGE', 'Afficher \'Serendipity\' avec un logo');
@define('POWERED_BY_SHOW_IMAGE_DESC', 'Affiche le logo Serendipity');
@define('INSTALL_TOP_AS_LINKS', 'Afficher le top pages sortantes / rfrantes en tant que liens ?');
@define('INSTALL_TOP_AS_LINKS_DESC', '\'Non\' : affichage en tant que texte seulement pour prvenir le spam par Google. \'Oui\' : affichage en tant que liens. Par dfaut, l\'option de la configuration gnrale est utilise.');

@define('SETTINGS_SAVED_AT', 'La nouvelle configuration a t enregistre  %s');
@define('PLUGIN_ITEM_DISPLAY', 'O le billet doit-il tre affich ?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'Dans la vue dtaille seulement');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'Page d\'accueil seulement');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'Sur la page d\'accueil et la vue dtaille');
@define('RSS_IMPORT_CATEGORY', 'Utiliser cette catgorie pour les billets  catgorie inconnue');
@define('ERROR_UNKNOWN_NOUPLOAD', 'Erreur : impossible d\'uploader le fichier. Peut-tre que la taille du fichier est plus grande que ce que votre serveur autorise. Vrifiez avec votre administrateur systme ou ditez votre fichier php.ini pour autoriser le tlchargement de fichiers plus volumineux.');
@define('COMMENTS_WILL_BE_MODERATED', 'Les commentaires posts doivent tre approuvs avant d\'tre affichs dans le blog.');
@define('YOU_HAVE_THESE_OPTIONS', 'Vous avez les possibilits suivantes :');
@define('THIS_COMMENT_NEEDS_REVIEW', 'Attention : ce commentaire doit tre approuv avant d\'tre publi.');
@define('DELETE_COMMENT', 'Supprimer le commentaire');
@define('APPROVE_COMMENT', 'Approuver le commentaire');
@define('REQUIRES_REVIEW', 'Doit tre revu');
@define('COMMENT_APPROVED', 'Le commentaire #%s a t approuv');
@define('COMMENT_DELETED', 'Le commentaire #%s a t supprim');
@define('VIEW', 'Afficher');
@define('COMMENT_ALREADY_APPROVED', 'Le commentaire #%s semble dj avoir t approuv');
@define('COMMENT_EDITED', 'Le commentaire slectionn a t modifi');
@define('HIDE', 'Cacher');
@define('VIEW_EXTENDED_ENTRY', 'Continuer  lire "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'Ce lien n\\\'est pas fait pour tre cliqu. Il contient le rtrolien de ce billet. Vous pouvez utiliser ce lien pour envoyer un ping ou crer un rtrolien vers ce billet  partir de votre blog. Pour copier le lien, faites un clic droit sur le lien, et slectionnez \\\'Copier le lien\\\' dans Internet Explorer ou \\\'Copier le lien\\\' dans Mozilla.');
@define('THIS_TRACKBACK_NEEDS_REVIEW', 'Attention : Ce rtrolien doit tre approuv avant qu\'il ne puisse tre affich.');
@define('DELETE_TRACKBACK', 'Supprimer le rtrolien');
@define('APPROVE_TRACKBACK', 'Approuver le rtrolien');
@define('TRACKBACK_APPROVED', 'Le rtrolien #%s a t approuv');
@define('TRACKBACK_DELETED', 'Le rtrolien #%s a t supprim');
@define('COMMENTS_MODERATE', 'Les commentaires ou rtroliens de ce billet doivent tre approuvs.');
@define('PLUGIN_SUPERUSER_HTTPS', 'Utiliser un accs scuris pour l\'authentification');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'Fait que le lien de l\'interface d\'administration montre vers un lien scuris (https). Attentioni : votre serveur doit tre configur pour accepter ce genre de liens.');
@define('INSTALL_SHOW_EXTERNAL_LINKS', 'Rendre les liens sortants cliquables ?');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '\'Non\' : Les liens sortants non vrifis (Top liens sortants, Top pages rfrantes, Commentaires) ne sont pas affichs/affichs en tant que texte seulement si possible pour prvenir le spam par Google (recommand). \'Oui\' : les liens non vrifis sont affichs en tant que liens. Notez que vous pouvez remplacer cette option localement dans les plugins pour la barre latrale.');
@define('PAGE_BROWSE_COMMENTS', 'Page %s de %s, %s commentaires au total');
@define('FILTERS', 'Filtres');
@define('FIND_ENTRIES', 'Trouver des billets');
@define('FIND_COMMENTS', 'Trouver des commentaires');
@define('FIND_MEDIA', 'Trouver des images');
@define('FILTER_DIRECTORY', 'Dossier');
@define('SORT_BY', 'Trier par');
@define('TRACKBACK_COULD_NOT_CONNECT', 'Pas de rtrolien envoy : la connexion n\'a pas pu tre tablie  %s sur le port %d');
@define('MEDIA', 'Document');
@define('MEDIA_LIBRARY', 'Mdiathque');
@define('ADD_MEDIA', 'Ajouter un document');
@define('ENTER_MEDIA_URL', 'Entrez un lien d\'un fichier  tlcharger :');
@define('ENTER_MEDIA_UPLOAD', 'Slectionnez un fichier  uploader :');
@define('SAVE_FILE_AS', 'Enregistrer le fichier sous :');
@define('STORE_IN_DIRECTORY', 'Enregistrer dans le dossier suivant : ');
@define('MEDIA_RENAME', 'Renommer ce fichier');
@define('IMAGE_RESIZE', 'Redimensionner cette image');
@define('MEDIA_DELETE', 'Supprimer ce fichier');
@define('FILES_PER_PAGE', 'Fichiers par page');
@define('CLICK_FILE_TO_INSERT', 'Cliquez sur le fichier que vous voulez insrer :');
@define('SELECT_FILE', 'Choisissez un fichier  insrer');
@define('MEDIA_FULLSIZE', 'Taille relle');
@define('CALENDAR_BOW_DESC', 'Le jour qui doit tre considr comme dbut de la semaine. Lundi par dfaut.');
@define('SUPERUSER', 'Administration du blog');
@define('ALLOWS_YOU_BLAHBLAH', 'Ajoute un lien  l\'administration de votre blog dans la barre latrale.');
@define('CALENDAR', 'Calendrier');
@define('SUPERUSER_OPEN_ADMIN', 'Aller  l\'administration');
@define('SUPERUSER_OPEN_LOGIN', 'Aller  l\'cran d\'authentification');
@define('INVERT_SELECTIONS', 'Inverser les slections');
@define('COMMENTS_DELETE_CONFIRM', 'tes-vous sr de vouloir supprimer les commentaires slectionns ?');
@define('COMMENT_DELETE_CONFIRM', 'tes-vous sr de vouloir supprimer le commentaire #%d, post par %s ?');
@define('DELETE_SELECTED_COMMENTS', 'Supprimer les commentaires slectionns');
@define('VIEW_COMMENT', 'Afficher le commentaire');
@define('VIEW_ENTRY', 'Afficher le billet');
@define('DELETE_FILE', 'Suppression du fichier intitul <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', 'Vous tes sur le point d\'effacer <b>%s</b>.<br />Si vous avez utilis ce fichier dans un de vos billets, les liens vers celui-ci seront invalides<br />tes-vous sr de vouloir continuer ?<br /><br />');
@define('TRACKBACK_SENDING', 'Envoie le rtrolien  l\'adresse %s...');
@define('TRACKBACK_SENT', 'Rtrolien effectu');
@define('TRACKBACK_FAILED', 'Rtrolien chou : %s');
@define('TRACKBACK_NOT_FOUND', 'Pas de rtrolien trouv.');
@define('TRACKBACK_URI_MISMATCH', 'Le rtrolien dtermin automatiquement ne correspond pas  l\'adresse cible.');
@define('TRACKBACK_CHECKING', 'Vrifie <u>%s</u> pour des rtroliens ventuels...');
@define('TRACKBACK_NO_DATA', 'L\'adresse cible ne contenait pas de donnes');
@define('TRACKBACK_SIZE', 'L\'adresse cible dpasse la taille de %s octets.');
@define('VIEWMODE_THREADED', 'Passer en mode vue groupe');
@define('COMMENTS_VIEWMODE_THREADED', 'Vue groupe');
@define('COMMENTS_VIEWMODE_LINEAR', 'Vue non groupe');
@define('DISPLAY_COMMENTS_AS', 'Afficher les commentaires en');
@define('PAGE_BROWSE_ENTRIES', 'Page %s de %s sur %s billets au total');
@define('ADD_MEDIA_BLAHBLAH', '<b>Ajouter un fichier  votre mdiathquei :</b><p>Vous permet d\'uploader des fichiers, ou de me dire une adresse internet de laquelle je peux les tlcharger. Si vous n\'avez pas d\'image approprie, vous pouvez faire une <a href="http://images.google.com" target="_blank">recherche d\'images avec Google</a>, les rsultats sont souvent intressants et toujours trs comiques :)</p><p><b>Choisissez une mthode :</b></p><br/>');
@define('COMMENTS_FILTER_SHOW', 'Afficher');
@define('COMMENTS_FILTER_ALL', 'Tous');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'Approuvs');
@define('COMMENTS_FILTER_NEED_APPROVAL', 'En attente d\'tre approuvs');
@define('RSS_IMPORT_BODYONLY', 'Mettre tout le texte import dans l\'introduction du billet au lieu de le rpartir sur l\'introduction et le corps du billet.');
@define('SYNDICATION_PLUGIN_FULLFEED', 'Afficher les billets complets dans le fil RSS (include le corps du billet)');
@define('MT_DATA_FILE', 'Fichier de donnes Movable Type');
@define('FORCE', 'Forcer');
@define('CREATE_AUTHOR', 'Crer l\'auteur \'%s\'.');
@define('CREATE_CATEGORY', 'Crer la catgorie \'%s\'.');
@define('MYSQL_REQUIRED', 'L\'extension MySQL doit tre active dans votre installation PHP pour pouvoir continuer.');
@define('COULDNT_CONNECT', 'Impossible de se connecter  la base de donnes MySQL : %s.');
@define('COULDNT_SELECT_DB', 'Impossible de slectionner une base de donnes : %s.');
@define('COULDNT_SELECT_USER_INFO', 'Impossible d\'accder aux informations d\'utilisateurs : %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'Impossible d\'accder aux informations de catgories : %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'Impossible d\'accder aux informations de billets : %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'Impossible d\'accder aux informations de commentaires : %s.');
@define('WEEK', 'Semaine');
@define('WEEKS', 'Semaines');
@define('MONTHS', 'Mois');
@define('DAYS', 'Jours');
@define('ARCHIVE_FREQUENCY', 'Frquence d\archivage des lments dans le calendrier');
@define('ARCHIVE_FREQUENCY_DESC', 'Intervalle dans le calendrier entre chaque lment de la liste');
@define('ARCHIVE_COUNT', 'Nombre d\'lments dans la liste');
@define('ARCHIVE_COUNT_DESC', 'Le nombre total de mois, semaines ou jours  afficher');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'Ci-dessous : une liste des plugins installs');
@define('SIDEBAR_PLUGIN', 'plugin de barre latrale');
@define('EVENT_PLUGIN', 'plugin d\'vnement');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'Cliquez ici pour installer un nouveau %s');
@define('VERSION', 'version');
@define('INSTALL', 'Installer');
@define('ALREADY_INSTALLED', 'Dj install');
@define('SELECT_A_PLUGIN_TO_ADD', 'Slectionnez le plugin que vous voulez installer');
@define('INSTALL_OFFSET', 'Dcalage de l\'heure serveur');
@define('STICKY_POSTINGS', 'Billets indlbiles');
@define('INSTALL_FETCHLIMIT', 'Billets  afficher sur la page d\'accueil');
@define('INSTALL_FETCHLIMIT_DESC', 'Nombre de billets  afficher par page dans l\'interface principale du blog');
@define('IMPORT_ENTRIES', 'Importer des billets');
@define('EXPORT_ENTRIES', 'Exporter des billets');
@define('IMPORT_WELCOME', 'Bienvenue dans l\'assistant d\'importation de Serendipity');
@define('IMPORT_WHAT_CAN', 'Ici vous pouvez importer des billets d\'autres logiciels de Blog');
@define('IMPORT_SELECT', 'Slectionnez le logiciel dont vous voulez importer les billets');
@define('IMPORT_PLEASE_ENTER', 'Compltez les informations requises ci-dessous');
@define('IMPORT_NOW', 'Importer maintenant !');
@define('IMPORT_STARTING', 'Importe les billets...');
@define('IMPORT_FAILED', 'Importation choue');
@define('IMPORT_DONE', 'Importation termine avec succs');
@define('IMPORT_WEBLOG_APP', 'Logiciel de Blog');
@define('EXPORT_FEED', 'Exporter le fil RSS complet');
@define('STATUS', 'Statut aprs importation');
@define('IMPORT_GENERIC_RSS', 'Importation gnrique de fils RSS');
@define('ACTIVATE_AUTODISCOVERY', 'Envoyer des traages aux liens trouvs dans le billet');
@define('WELCOME_TO_ADMIN', 'Bienvenue dans l\'interface d\'administration de Serendipity');
@define('PLEASE_ENTER_CREDENTIALS', 'Entrez vos donnes d\'authentification ci-dessous.');
@define('ADMIN_FOOTER_POWERED_BY', 'Propuls par Serendipity %s et PHP %s');
@define('INSTALL_USEGZIP', 'Utiliser la compression gzip des pages');
@define('INSTALL_USEGZIP_DESC', 'Pour augmenter la vitesse de transfert des pages, Serendipity peut comprimer les pages envoyes au navigateur du visiteur (si le navigateur peut interprter cette compression). Recommand.');
@define('INSTALL_SHOWFUTURE', 'Afficher les billets futurs');
@define('INSTALL_SHOWFUTURE_DESC', 'Si cette option est active, les billets  paratre seront affichs dans votre blog. Par dfaut, ces billets ne seront affichs qu\' la date de publication dfinie.');
@define('INSTALL_DBPERSISTENT', 'Utiliser les connexions permanentes');
@define('INSTALL_DBPERSISTENT_DESC', 'Active l\'utilisation de connexions permanentes  la base de donnes. Pour plus d\'informations, consultez le <a href="http://php.net/manual/features.persistent-connections.php" target="_blank">manuel de PHP</a>. Non recommand en rgle gnrale.');
@define('NO_IMAGES_FOUND', 'Pas d\'images trouves');
@define('PERSONAL_SETTINGS', 'Rglages personnels');
@define('REFERER', 'Page rfrante');
@define('NOT_FOUND', 'Non trouv');
@define('NOT_WRITABLE', 'Protg en criture');
@define('WRITABLE', 'Accessible en criture');
@define('PROBLEM_DIAGNOSTIC', ' cause d\'erreurs survenues lors de l\'analyse prventive, vous ne pourrez continuer l\'installation qu\'aprs avoir corrig les erreurs mentionnes ci-dessus.');
@define('SELECT_INSTALLATION_TYPE', 'Choisissez le type d\'installation que vous voulez utiliser');
@define('WELCOME_TO_INSTALLATION', 'Bienvenue dans l\'assistant d\'installation de Serendipity');
@define('FIRST_WE_TAKE_A_LOOK', 'Tout d\'abord, nous allons faire une analyse prventive de votre installation et essayer de diagnostiquer d\'ventuels problmes de compatibilit.');
@define('ERRORS_ARE_DISPLAYED_IN', 'Les erreurs sont affiches en %s, les recommandations en %s et les succs en %s');
@define('RED', 'rouge');
@define('YELLOW', 'jaune');
@define('GREEN', 'vert');
@define('PRE_INSTALLATION_REPORT', 'Rapport pr-installation de Serendipity v%s');
@define('RECOMMENDED', 'Recommand');
@define('ACTUAL', 'Actuel');
@define('PHPINI_CONFIGURATION', 'configuration php.ini');
@define('PHP_INSTALLATION', 'Installation PHP');
@define('THEY_DO', 'ils font');
@define('THEY_DONT', 'ils ne font pas');
@define('SIMPLE_INSTALLATION', 'Installation rapide');
@define('EXPERT_INSTALLATION', 'Installation expert');
@define('COMPLETE_INSTALLATION', 'Installation complte');
@define('WONT_INSTALL_DB_AGAIN', 'la base de donnes ne sera pas rinstalle');
@define('CHECK_DATABASE_EXISTS', 'Vrifie si la base de donnes et les tableaux ncessaires sont dj prsents');
@define('CREATING_PRIMARY_AUTHOR', 'Cration de l\'auteur principal \'%s\'');
@define('SETTING_DEFAULT_TEMPLATE', 'Dfinition du thme par dfaut');
@define('INSTALLING_DEFAULT_PLUGINS', 'Installation des plugins par dfaut');
@define('SERENDIPITY_INSTALLED', 'Serendipity a t install avec succs');
@define('VISIT_BLOG_HERE', 'Accder  votre nouveau blog');
@define('THANK_YOU_FOR_CHOOSING', 'Merci d\'avoir choisi Serendipity');
@define('ERROR_DETECTED_IN_INSTALL', 'Une erreur a t dtecte pendant l\'installation');
@define('OPERATING_SYSTEM', 'Systme d\'exploitation');
@define('WEBSERVER_SAPI', 'SAPI Serveur');
@define('IMAGE_ROTATE_LEFT', 'Basculer l\'image de 90 degrs vers la droite');
@define('IMAGE_ROTATE_RIGHT', 'Basculer l\'image de 90 degrs vers la gauche');
@define('TEMPLATE_SET', '\'%s\' a t dfini comme thme actif');
@define('SEARCH_ERROR', 'La fonction de recherche n\'a pas fonctionn comme prvu. Note  l\'administrateur de ce blog : cette erreur peut survenir si des cls d\'index manquent dans la base de donnes. Avec des systmes MySQL, l\'utilisateur avec lequel Serendipity se connecte  la base de donnes doit avoir les privilges ncessaires pour excuter la commande suivante : <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre>. Voici le message d\'erreur complet de la base de donnes : <pre>%s</pre>');
@define('EDIT_THIS_CAT', 'diter "%s"');
@define('CATEGORY_REMAINING', 'Effacer cette catgorie et dplacer tous les billets dans cette catgorie');
@define('CATEGORY_INDEX', 'Voici une liste des catgories disponibles pour vos billets');
@define('NO_CATEGORIES', 'Pas de catgories');
@define('RESET_DATE', 'Rinitialiser la date');
@define('RESET_DATE_DESC', 'Cliquez ici pour remettre la date  l\'heure actuelle');
@define('PROBLEM_PERMISSIONS_HOWTO', 'Les droits d\'accs peuvent tre changs en ligne de commande par la commande : `<em>%s</em>` sur le rpertoire qui fait dfaut, ou en le faisant  l\'aide d\'un programme FTP.');
@define('WARNING_TEMPLATE_DEPRECATED', 'Attention : les templates du thme que vous avez choisi utilisent des fonctions primes. Vous devriez les mettre  jour si possible.');
@define('ENTRY_PUBLISHED_FUTURE', 'Ce billet n\'a pas encore t publi.');
@define('ENTRIES_BY', 'Billets par %s');
@define('PREVIOUS', 'Prcdent');
@define('NEXT', 'Suivant');
@define('APPROVE', 'Valider');
@define('DO_MARKUP_DESCRIPTION', 'Transforme les balises dans le texte (smileys, raccourcis via *, /, _, ...). La dsactiver prserva tout le code HTML dans le texte.');
@define('CATEGORY_ALREADY_EXIST', 'Une catgorie avec le nom "%s" existe dj');
@define('IMPORT_NOTES', 'Remarque :');
@define('ERROR_FILE_FORBIDDEN', 'Vous n\'tes pas autoris  tlcharger des fichiers avec ce contenu');
@define('ADMIN', 'Administration');
@define('ADMIN_FRONTPAGE', 'Page d\'accueil');
@define('QUOTE', 'Citation');
@define('IFRAME_SAVE', 'Serendipity est maintenant en train de sauvegarder votre billet, de crer un point de restauration et de tenter des appels XML-RPC. Cela risque de prendre un peu de temps..');
@define('IFRAME_SAVE_DRAFT', 'Une copie du billet a t sauvegarde');
@define('IFRAME_PREVIEW', 'Serendipity est en train de prparer la page pour prvisualiser votre billet...');
@define('IFRAME_WARNING', 'Votre navigateur n\'est pas compatible avec les iframes. Ouvrez le fichier serendipity_config.inc.php et passez la variable $serendipity[\'use_iframe\']  FALSE.');
@define('NONE', 'aucun');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 'Paramtres par dfaut pour les nouveaux billets');
@define('UPGRADE', 'Mise  jour');
@define('UPGRADE_TO_VERSION', 'Mise  jour vers la version %s');
@define('DELETE_DIRECTORY', 'Supprimer le rpertoire');
@define('DELETE_DIRECTORY_DESC', 'Vous tes sur le point de supprimer le contenu d\'un rpertoire contenant des fichiers mdia qui peuvent tre utiliss par certains de vos billets.');
@define('FORCE_DELETE', 'Suprimer TOUS les fichiers de ce rpertoire, y compris ceux inconnus de Serendipity');
@define('CREATE_DIRECTORY', 'Crer un rpertoire');
@define('CREATE_NEW_DIRECTORY', 'Crer un nouveau rpertoire');
@define('CREATE_DIRECTORY_DESC', 'Ici vous pouvez crer un rpertoire qui pourra contenir des fichiers mdias. Choisissez un nom pour votre rpertoire ainsi que, si vous voulez, le rpertoire parent dans lequel il sera plac.');
@define('BASE_DIRECTORY', 'Rpertoire de base');
@define('USERLEVEL_EDITOR_DESC', 'diteur standard');
@define('USERLEVEL_CHIEF_DESC', 'diteur en chef');
@define('USERLEVEL_ADMIN_DESC', 'Administrateur');
@define('USERCONF_USERLEVEL', 'Niveaux d\'accs');
@define('USERCONF_USERLEVEL_DESC', 'Ce niveau est utilis pour dterminer quel type d\'accs cet utilisateur aura sur le blog');
@define('USER_SELF_INFO', 'Identifi en tant que %s (%s)');
@define('ADMIN_ENTRIES', 'Billets');
@define('RECHECK_INSTALLATION', 'Revrifier l\'installation');
@define('IMAGICK_EXEC_ERROR', 'Impossible d\'excuter : "%s", erreur: %s, retourne la valeur: %d');
@define('INSTALL_OFFSET_DESC', 'Entrez le nombre d\'heures entre celle de votre serveur web (current: %clock%) et votre fuseau horaire');
@define('UNMET_REQUIREMENTS', 'Les pr-requis ne sont pas remplis : %s');
@define('CHARSET', 'Charset');
@define('AUTOLANG', 'Utiliser le langage par dfaut du navigateur de l\'utilisateur');
@define('AUTOLANG_DESC', 'Si autoris, cela utilisera les rglages de langage du navigateur du visiteur pour dterminer le langage par dfaut de vos billets et le langage de votre interface.');
@define('INSTALL_AUTODETECT_URL', 'Autodtection utilise HTTP-Host');
@define('INSTALL_AUTODETECT_URL_DESC', 'Si positionn  "true", Serendipity s\'assurera que l\'hte HTTP qui a t utilis par le visiteur utilise les rglages de votre base d\'URLs. Autoriser cela vous permettra d\'utiliser plusieurs noms de domaines pour votre blog Serendipity, et utilisera le domaine pour tout les liens suivants utiliss par le visiteur pour accder  votre blog.');
@define('CONVERT_HTMLENTITIES', 'Essayer de convertir automatiquement les balises HTML ?');
@define('EMPTY_SETTING', 'Vous n\'avez pas spcifi de valeur correcte pour "%s" !');
@define('USERCONF_REALNAME', 'Nom rel');
@define('USERCONF_REALNAME_DESC', 'Le nom complet de l\'auteur. C\'est le nom qui sera vu par les lecteurs');
@define('HOTLINK_DONE', 'Lien du fichier.<br />Fait.');
@define('ENTER_MEDIA_URL_METHOD', 'Mode de recherche :');
@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Remarque : si vous choisissez de faire un lien sur le serveur, assurez-vous d\'avoir la permission de le faire, ou que le site vous appartienne. Faire un lien vous permet d\'utiliser des images qui ne sont pas sur le site sans avoir  les stocker localement sur le serveur.');
@define('MEDIA_HOTLINKED', 'Li');
@define('FETCH_METHOD_IMAGE', 'Tlchargement de l\'image vers votre serveur');
@define('FETCH_METHOD_HOTLINK', 'Lien vers le serveur');
@define('DELETE_HOTLINK_FILE', 'Suppression du fichier li nomm <b>%s</b>');
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'Montrer l\'adresse E-Mail ?');
@define('IMAGE_MORE_INPUT', 'Ajouter plusieurs images');
@define('BACKEND_TITLE', 'Informations complmentaires dans le plugin de l\'cran de configuration');
@define('BACKEND_TITLE_FOR_NUGGET', 'Ici vous pouvez dfinir une chaine personnalise qui sera affiche dans le plugin de l\'cran de configuration avec la description HTML du plugin Nugget. Si vous avez plusieurs nuggets HTML sans titre cela vous permettra de les distinguer les uns des autres.');
@define('CATEGORIES_ALLOW_SELECT', 'Permettre aux visiteurs d\'afficher plusieurs catgories  la fois ?');
@define('CATEGORIES_ALLOW_SELECT_DESC', 'Si cette option est autorise, une case  cocher sera positionne  ct de chaque catgorie dans le plugin de la barre latrale. Les utilisateurs pourront ainsi cocher ces cases pour visualiser les billets correspondants.');
@define('PAGE_BROWSE_PLUGINS', 'Page %s de %s, avec un total de %s plugins.');
@define('INSTALL_CAT_PERMALINKS', 'Rtroliens');
@define('INSTALL_CAT_PERMALINKS_DESC', 'Permet de crer des modles de liens permanents pour accder aux diverses fonctions de votre blog. Nous suggrons d\'utiliser les valeurs par dfaut. Si vous dcidez de les changer, vous devriez essayer d\'utiliser la valeur %id% quand c\'est possible : vous pouvez ainsi viter que Serendipity accde  la base de donnes pour dterminer l\'adresse cible.');
@define('INSTALL_PERMALINK', 'Structure des rtroliens');
@define('INSTALL_PERMALINK_DESC', 'Ici vous pouvez dfinir le chemin relatif  l\adresse de votre blog par lequel on pourra accder  tous les billets. Vous pouvez utiliser les variables %id% (identifiant), %title% (titre du billet), %day% (jour), %month% (mois), %year% (anne) et n\'importe quels autres caractres.');
@define('INSTALL_PERMALINK_AUTHOR', 'Structure des rtroliens par auteur');
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'Ici vous pouvez dfinir le chemin relatif  l\adresse de votre blog par lequel on pourra accder aux billets classs par auteur. Vous pouvez utiliser les variables %id% (identifiant), %realname% (nom rel), %username% (pseudo), %email% et n\'importe quels autres caractres.');
@define('INSTALL_PERMALINK_CATEGORY', 'Structure des rtroliens par catgorie');
@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Ici vous pouvez dfinir le chemin relatif  l\'adresse de votre blog par lequel on pourra accder aux billets classs par catgorie. Vous pouvez utiliser les variables %id% (identifiant), %name% (nom), %description% et n\'importe quels autres caractres.');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Structure des fils RSS par catgorie');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Ici vous pouvez dfinir le chemin relatif  l\'adresse de votre blog par lequel on pourra accder aux fils RSS des catgories. Vous pouvez utiliser les variables %id% (identifiant), %name% (nom), %description% et n\'importe quels autres caractres.');
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'Chemin d\'accs aux archives');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'Chemin d\'accs  l\'archive');
@define('INSTALL_PERMALINK_CATEGORIESPATH', 'Chemin d\'accs aux catgories');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'Adresse de dsinscription des commentaires');
@define('INSTALL_PERMALINK_DELETEPATH', 'Adresse pour effacer les commentaires');
@define('INSTALL_PERMALINK_APPROVEPATH', 'Adresse pour l\'autorisation des commentaires');
@define('INSTALL_PERMALINK_FEEDSPATH', 'Chemin d\'accs aux fils RSS');
@define('INSTALL_PERMALINK_PLUGINPATH', 'Chemin d\'accs  un plugin');
@define('INSTALL_PERMALINK_ADMINPATH', 'Chemin d\'accs  l\'administration');
@define('INSTALL_PERMALINK_SEARCHPATH', 'Chemin d\'accs  la recherche');
@define('INSTALL_CAL', 'Type de calendrier');
@define('INSTALL_CAL_DESC', 'Choisissez votre format de calendrier prfr');
@define('REPLY', 'Rpondre');
@define('USERCONF_GROUPS', 'Appartenance de groupe');
@define('USERCONF_GROUPS_DESC', 'Cet utilisateur appartient aux groupes suivants. Des appartenances multiples sont possibles.');
@define('MANAGE_GROUPS', 'Administrer les groupes');
@define('DELETED_GROUP', 'Groupe #%d %s effac.');
@define('CREATED_GROUP', 'Un nouveau groupe intitul %s a t cr');
@define('MODIFIED_GROUP', 'Les proprits du groupe %s ont t modifies');
@define('GROUP', 'Groupe');
@define('CREATE_NEW_GROUP', 'Crer un nouveau groupe');
@define('DELETE_GROUP', 'Vous tes sur le point d\'effacer le groupe  #%d %s. tes-vous sr ?');
@define('USERLEVEL_OBSOLETE', 'NOTICE : l\'attribut "niveau d\'accs" n\'est plus utilis que pour assurer la compatibilit descendante des plugins et comme systme d\'autorisation de secours. Les niveaux d\'autorisation sont maintenant grs par l\appartenance  un ou plusieurs groupes d\'utilisateurs !');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'Identifiant FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'L\'identifiant du fil que vous voulez publier');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'Image FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'Nom de l\'image  afficher (laisser le champ vide pour afficher un compteur), situe sur feedburner.com. Exemple : "fbapix.gif"');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'Titre FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'Titre  afficher  ct de l\'image (ou laisser vide pour aucun)');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'Info-bulle de l\'image FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'Contenu de l\info-bulle qui s\'affiche quand on passe sur l\'image FeedBurner (laisser vide pour aucune)');

@define('SEARCH_TOO_SHORT', 'Votre recherche doit comporter plus de 3 caractres. Pour faire des recherches avec des mots courts, vous pouvez ajouter *  la fin du mot (comme s9y*, par exemple).');
@define('INSTALL_DBPORT', 'Port de la base de donnes');
@define('INSTALL_DBPORT_DESC', 'Le port  utiliser pour se connecter  la base de donnes');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'Interface utilisateur : Services externes');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'Interface utilisateur : Fonctionnalits');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'Interface utilisateur : Conversions totales');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'Interface utilisateur : Vues');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'Interface utilisateur : Autour des billets');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'Administration : diteur');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'Administration : Gestion des utilisateurs');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'Administration : Mtadonnes');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'Administration : Thmes');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'Administration : Fonctionnalits');
@define('PLUGIN_GROUP_IMAGES', 'Images');
@define('PLUGIN_GROUP_ANTISPAM', 'Antispam');
@define('PLUGIN_GROUP_MARKUP', 'Balises');
@define('PLUGIN_GROUP_STATISTICS', 'Statistiques');
@define('PERMISSION_PERSONALCONFIGURATION', 'personalConfiguration : Accs  la configuration personnelle');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'personalConfigurationUserlevel : Changement des niveaux d\'autorisation des utilisateurs');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'personalConfigurationNoCreate : Changement du droit de cration de billets');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'personalConfigurationRightPublish : Changement du droit de publication de billets');
@define('PERMISSION_SITECONFIGURATION', 'siteConfiguration : Accs  la configuration du systme');
@define('PERMISSION_BLOGCONFIGURATION', 'blogConfiguration : Accs  la configuration du blog');
@define('PERMISSION_ADMINENTRIES', 'adminEntries : Administration des billets');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers : Administration des billets d\'autres utilisateurs');
@define('PERMISSION_ADMINIMPORT', 'adminImport : Importation de billets');
@define('PERMISSION_ADMINCATEGORIES', 'adminCategories : Administration des catgories');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers : Administration des catgories d\'autres utilisateurs');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminCategoriesDelete : Suppression de catgories');
@define('PERMISSION_ADMINUSERS', 'adminUsers : Administration des utilisateurs');
@define('PERMISSION_ADMINUSERSDELETE', 'adminUsersDelete : Suppression d\'utilisateurs');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminUsersEditUserlevel : Changement des niveaux d\'autorisation des utilisateurs');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame : Administration des utilisateurs du mme groupe');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers : Administration des utilisateurs d\'autres groupes');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminUsersCreateNew : Ajout de nouveaux utilisateurs');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUsersGroups : Administration des groupes d\'utilisateurs');
@define('PERMISSION_ADMINPLUGINS', 'adminPlugins : Administration des plugins');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers : Administration des plugins d\'autres utilisateurs');
@define('PERMISSION_ADMINIMAGES', 'adminImages : Administration des documents');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminImagesDirectories : Administration des catgories de documents');
@define('PERMISSION_ADMINIMAGESADD', 'adminImagesAdd : Ajout de nouveaux documents');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete : Suppression de documents');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers : Administration des documents d\'autres utilisateurs');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView : Affichage de documents');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync : Synchronisation des miniatures');
@define('PERMISSION_ADMINCOMMENTS', 'adminComments : Administration des commentaires de billets');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplates : Administration des thmes');
@define('INSTALL_BLOG_EMAIL', 'Adresse Email du blog');
@define('INSTALL_BLOG_EMAIL_DESC', 'Dfinit l\'adresse email qui est utilise pour les messages sortants, pour permettre aux destinataires d\'y rpondre. Assurez-vous que cette adresse est reconnue par le serveur mail qui sera utilis pour l\'envoi : beaucoup de serveurs refusent l\'envoi de messages contenant des adresses inconnues.');
@define('CATEGORIES_PARENT_BASE', 'N\'afficher que les sous-catgories de...');
@define('CATEGORIES_PARENT_BASE_DESC', 'Vous pouvez choisir une catgorie pour que seulement les sous-catgories de celle-ci soient affiches.');
@define('CATEGORIES_HIDE_PARALLEL', 'Cacher les catgories ne faisant pas partie de l\'arborescence');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'Si vous dsirez cacher les catgories qui font partie d\'une autre arborescence de catgories, vous devez activer cette option. Cette fonctionnalit est surtout intressante si vous utilisez un multi-blog avec le plugin "Proprits/Thmes de catgories".');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminImagesViewOthers : Affichage de documents d\'autres utilisateurs');
@define('CHARSET_NATIVE', 'Natif');
@define('INSTALL_CHARSET', 'Slection de la table de caractres');
@define('INSTALL_CHARSET_DESC', 'Vous permet de dfinir la table de caractres  utiliser : UTF-8 ou Natif (ISO, EUC, ...). Quelques langues ne sont disponibles qu\'en UTF-8, dans ce cas cette option n\'aura pas d\'effet. UTF-8 est recommand pour de nouvelles installations. Attention : ne changez pas cette option si vous avez dj cre des billets avec des caractres spciaux - cela pourrait entraner un affichage corrompu de ces caractres. Vous trouverez plus d\'informations  ce sujet  l\'adresse suivamte : http://www.s9y.org/index.php?node=46 (en anglais)');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Activer l\'interface de programmation');
@define('CALENDAR_EXTEVENT_DESC', 'Si active, cette option permet aux plugins d\'accder au calendrier pour y afficher leurs propres vnements. Ne l\'activez que si vous avez des plugins utilisant cette fonctionnalit, autrement cela ne ferait que diminuer la performance de votre blog.');
@define('XMLRPC_NO_LONGER_BUNDLED', 'L\'interface de programmation XML-RPC de Serendipity n\'est plus incluse automatiquement  cause de failles de scurit dans celle-ci et parce que trs peu de personnes l\'utilisent. Pour l\'activer, vous devez installer le plugin XML-RPC. L\'adresse que vous utilisez dans vos applications NE CHANGERA PAS - ds que vous aurez install le plugin, vous pourrez  nouveau accder  l\'interface.');
@define('PERM_READ', 'Autorisation de lecture');
@define('PERM_WRITE', 'Autorisation d\'criture');

@define('PERM_DENIED', 'Autorisation refuse.');
@define('INSTALL_ACL', 'Appliquer les autorisations pour les catgories');
@define('INSTALL_ACL_DESC', 'Si vous activez cette option, les autorisations que vous dfinissez pour les catgories seront utilises pour les utilisateurs authentifis visitant votre blog. Autrement, les autorisations ne sont PAS vrifies, mais votre blog sera un peu plus rapide. Si vous n\'avez pas besoin d\'autorisations multi-utilisateurs pour votre blog, vous devriez dsactiver cette option.');
@define('PLUGIN_API_VALIDATE_ERROR', 'Syntaxe non valide pour l\'option "%s". Une valeur de type "%s" est requise.');
@define('USERCONF_CHECK_PASSWORD', 'Ancien mot de passe');
@define('USERCONF_CHECK_PASSWORD_DESC', 'Si vous changez le mot de passe dans le champ ci-dessus, vous devez entrer le mot de passe actuel dans ce champ.');
@define('USERCONF_CHECK_PASSWORD_ERROR', 'Vous n\'avez pas entr l\'ancien mot de passe correct, et vous n\'tes pas autoris  dfinir un nouveau mot de passe. Les donnes n\'ont pas t sauvegardes.');
@define('ERROR_XSRF', 'Votre navigateur n\'a pas envoy un HTTP-Referer (adresse rfrante) valide. Cela peut avoir t caus par un navigateur/proxy mal configur ou une intervention malveillante externe. L\'action que vous vouliez excuter a t annule.');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Ici vous pouvez dfinir la structure relative de l\'adresse par laquelle on peut accder aux fils RSS d\'utilisateurs spcifiques. Vous pouvez utiliser les variables %id% (identifiant), %realname% (nom rel), %username% (pseudo), %email% (email) et les caractres de votre choix dans l\'adresse cible.');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Structure des rtroliens aux fils RSS d\'auteurs');
@define('INSTALL_PERMALINK_AUTHORSPATH', 'Chemin des auteurs');
@define('AUTHORS', 'Auteurs');
@define('AUTHORS_ALLOW_SELECT', 'Autoriser les visiteurs  afficher plusieurs auteurs  la fois ?');
@define('AUTHORS_ALLOW_SELECT_DESC', 'Si cette option est active, une bote de slection sera affiche  ct de chaque nom d\'utilisateur dans ce plugin de barre latrale. Les visiteurs peuvent alors faire une slection d\'auteurs dont ils veulent afficher les billets.');
@define('AUTHOR_PLUGIN_DESC', 'Affiche une liste d\'auteurs');
@define('CATEGORY_PLUGIN_TEMPLATE', 'Activer les templates Smarty ?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'Si cette option est active, le plugin utilisera les fonctionnalits de Smarty pour afficher la liste des catgories. Cela permet de changer l\'affichage de la liste en modifiant le fichier "plugin_categories.tpl". N\'utilisez cette option que si vous avez besoin d\'adapter l\'affichage des catgories comme cette fonctionnalit a un impact sur les performances de votre blog.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'Afficher le nombre de billets par catgorie ?');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'Afficher le nombre d\'articles par auteur ?');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'Si cette option est active, le nombre de billets cres par cet auteur seront affichs  ct de son nom, entre parenthses.');
@define('CUSTOM_ADMIN_INTERFACE', 'Interface d\'administration sur mesure disponible');

@define('COMMENT_NOT_ADDED', 'Votre commentaire n\'a pas pu tre ajout pour l\'une des raisons suivantes : les commentaires ne sont pas autoriss pour ce billet, vous avez entr des donnes erronnes ou votre commentaire a t coup par le filtre anti-spam. ');
@define('INSTALL_TRACKREF', 'Activer le dpistage des adresses rfrantes ?');
@define('INSTALL_TRACKREF_DESC', 'Si cette option est active, vous pourrez voir quels sites ont des liens sur vos billets. Cette option est souvent utilise pour faire du spam, alors vous pouvez la dsactiver si vous le dsirez.');
@define('CATEGORIES_HIDE_PARENT', 'Cacher la catgorie suprieure slectionne ?');
@define('CATEGORIES_HIDE_PARENT_DESC', 'Si vous limitez la liste des catgories  une catgorie spcifique, vous verrez que par dfaut elle est incluse dans la liste des catgories. Si vous dsactivez cette option, cette catgorie ne sera plus affiche.');
@define('WARNING_NO_GROUPS_SELECTED', 'Attention : vous n\'avez pas slectionn d\'appartenance de groupe. Comme vous risquez de vous exclure vous-mme de la gestion des groupes d\'utilisateurs, vos modifications n\'ont pas t enregistres.');
@define('INSTALL_RSSFETCHLIMIT', 'Entries to display in Feeds');
@define('INSTALL_RSSFETCHLIMIT_DESC', 'Number of entries to display for each page on the RSS Feed.');
@define('INSTAL_DB_UTF8', 'Enable DB-charset conversion');
@define('INSTAL_DB_UTF8_DESC', 'Issues a MySQL "SET NAMES" query to indicate the required charset for the database. Turn this on or off, if you see weird characters in your blog.');
@define('ONTHEFLYSYNCH', 'Enable on-the-fly media synchronization');
@define('ONTHEFLYSYNCH_DESC', 'If enabled, Serendipity will compare the media database with the files stored on your server and synchronize the database and directory contents.');
@define('USERCONF_CHECK_USERNAME_ERROR', 'The username cannot be left blank.');
@define('FURTHER_LINKS', 'Further Links');
@define('FURTHER_LINKS_S9Y', 'Serendipity Homepage');
@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity Documentation');
@define('FURTHER_LINKS_S9Y_BLOG', 'Official Blog');
@define('FURTHER_LINKS_S9Y_FORUMS', 'Forums');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(Comment removed)');

@define('CURRENT_AUTHOR', 'Current author');

@define('WORD_NEW', 'New');
@define('SHOW_MEDIA_TOOLBAR', 'Show toolbar within media selector popup?');
@define('MEDIA_KEYWORDS', 'Media keywords');
@define('MEDIA_KEYWORDS_DESC', 'Enter a list of ";" separated words that you want to use as pre-defined keywords for media items.');
@define('MEDIA_EXIF', 'Import EXIF/JPEG image data');
@define('MEDIA_EXIF_DESC', 'If enabled, existing EXIF/JPEG metadata of images will be parsed and stored in the database for display in the media gallery.');
@define('MEDIA_PROP', 'Media properties');


@define('GO_ADD_PROPERTIES', 'Go & enter properties');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
@define('MEDIA_PROPERTY_COMMENT1', 'Short Comment');
@define('MEDIA_PROPERTY_COMMENT2', 'Long Comment');
@define('MEDIA_PROPERTY_TITLE', 'Title');
@define('MEDIA_PROP_DESC', 'Enter a list of ";" separated property fields you want to define for each media file');
@define('MEDIA_PROP_MULTIDESC', '(You can append ":MULTI" after any item to indicate that this item will contain long text instead of just some characters)');

@define('STYLE_OPTIONS_NONE', 'This theme/style has no specific options. To see how your template can specify options, read the Technical Documentation on www.s9y.org about "Configuration of Theme options".');
@define('STYLE_OPTIONS', 'Theme/Style options');

@define('PLUGIN_AVAILABLE_COUNT', 'Total: %d plugins.');

@define('SYNDICATION_RFC2616', 'Activate strict RFC2616 RSS-Feed compliance');
@define('SYNDICATION_RFC2616_DESC', 'NOT Enforcing RFC2616 means that all Conditional GETs to Serendipity will return entries last modified since the time of the last request. With that setting to "false", your visitors will get all articles since their last request, which is considered a good thing. However, some Agents like Planet act weird, if that happens, at it also violates RFC2616. So if you set this option to "TRUE" you will comply with that RFC, but readers of your RSS feed might miss items in their holidays. So either way, either it hearts Aggregators like Planet, or it hurts actual readers of your blog. If you are facing complaints from either side, you can toggle this option. Reference: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
@define('MEDIA_PROPERTY_DATE', 'Associated Date');
@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
@define('FILENAME_REASSIGNED', 'Automagically assigned new file name: %s');
@define('MEDIA_UPLOAD_SIZE', 'Max. file upload size');
@define('MEDIA_UPLOAD_SIZE_DESC', 'Enter the maximum filesize for uploaded files in bytes. This setting can be overruled by server-side settings in PHP.ini: upload_max_filesize, post_max_size, max_input_time all take precedence over this option. An empty string means to only use the server-side limits.');
@define('MEDIA_UPLOAD_SIZEERROR', 'Error: You cannot upload files larger than %s bytes!');
@define('MEDIA_UPLOAD_MAXWIDTH', 'Max. width of image files for upload');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Enter the maximum image width in pixels for uploaded images.');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'Max. height of image files for upload');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Enter the maximum image height in pixels for uploaded images.');
@define('MEDIA_UPLOAD_DIMERROR', 'Error: You cannot upload image files larger than %s x %s pixels!');

@define('MEDIA_TARGET', 'Target for this link');
@define('MEDIA_TARGET_JS', 'Popup window (via JavaScript, adaptive size)');
@define('MEDIA_ENTRY', 'Isolated Entry');
@define('MEDIA_TARGET_BLANK', 'Popup window (via target=_blank)');

@define('MEDIA_DYN_RESIZE', 'Allow dynamic image resizing?');
@define('MEDIA_DYN_RESIZE_DESC', 'If enabled, the media selector can return images in any requested size via a GET variable. The results are cached, and thus can create a large filebase if you make intensive use of it.');

@define('MEDIA_DIRECTORY_MOVED', 'Directory and files were successfully moved to %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Directory and files could not be moved to %s!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'On Non-MySQL databases, iterating through every article to replace the old directory URLs with new directory URLs is not possible. You will need to manually edit your entries to fix new URLs. You can still move your old directory back to where it was, if that is too cumbersome for you.');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
@define('PLUGIN_ACTIVE', 'Active');
@define('PLUGIN_INACTIVE', 'Inactive');
@define('PREFERENCE_USE_JS', 'Enable advanced JS usage?');
@define('PREFERENCE_USE_JS_DESC', 'If enabled, advanced JavaScript sections will be enabled for better usability, like in the Plugin Configuration section you can use drag and drop for re-ordering plugins.');

@define('PREFERENCE_USE_JS_WARNING', '(This page uses advanced JavaScripting. If you are having functionality issues, please disable the use of advanced JS usage in your personal preferences or disable your browser\'s JavaScript)');


@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
@define('USERCONF_CREATE', 'Disable user / forbid activity?');
@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
@define('PINGBACK_SENT', 'Pingback successful');
@define('PINGBACK_FAILED', 'Pingback failed: %s');
@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
@define('SET_TO_MODERATED', 'Moderate');
@define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
@define('CENTER', 'center');
